diff -uNr mutt-1.5.14.orig/globals.h mutt-1.5.14/globals.h
--- mutt-1.5.14.orig/globals.h	2007-01-31 04:49:02.000000000 +0900
+++ mutt-1.5.14/globals.h	2007-02-26 00:04:04.000000000 +0900
@@ -35,6 +35,7 @@
 WHERE char *AliasFmt;
 WHERE char *AttachSep;
 WHERE char *Attribution;
+WHERE char *AttachCharset;
 WHERE char *AttachFormat;
 WHERE char *Charset;
 WHERE char *ComposeFormat;
diff -uNr mutt-1.5.14.orig/handler.c mutt-1.5.14/handler.c
--- mutt-1.5.14.orig/handler.c	2005-12-17 03:46:59.000000000 +0900
+++ mutt-1.5.14/handler.c	2007-02-26 00:04:04.000000000 +0900
@@ -1749,6 +1749,8 @@
     if (charset && Charset)
       cd = mutt_iconv_open (Charset, charset, M_ICONV_HOOK_FROM);
   }
+  else if (istext && b->charset)
+    cd = mutt_iconv_open (Charset, b->charset, M_ICONV_HOOK_FROM);
 
   fseeko (s->fpin, b->offset, 0);
   switch (b->encoding)
diff -uNr mutt-1.5.14.orig/init.h mutt-1.5.14/init.h
--- mutt-1.5.14.orig/init.h	2006-11-21 02:49:08.000000000 +0900
+++ mutt-1.5.14/init.h	2007-02-26 00:06:26.000000000 +0900
@@ -215,6 +215,20 @@
   ** If set, Mutt will prompt you for carbon-copy (Cc) recipients before
   ** editing the body of an outgoing message.
   */  
+  { "attach_charset",    DT_STR,  R_NONE, UL &AttachCharset, UL 0 },
+  /*
+  ** .pp
+  ** This variable is a colon-separated list of character encoding
+  ** schemes for text file attachments.
+  ** If unset, $$charset value will be used instead.
+  ** For example, the following configuration would work for Japanese
+  ** text handling:
+  ** .pp
+  **   set attach_charset="iso-2022-jp:euc-jp:shift_jis:utf-8"
+  ** .pp
+  ** Note: "iso-2022-*" must be put at the head of the value as shown above
+  ** if included.
+  */
   { "attach_format",	DT_STR,  R_NONE, UL &AttachFormat, UL "%u%D%I %t%4n %T%.40d%> [%.7m/%.10M, %.6e%?C?, %C?, %s] " },
   /*
   ** .pp
@@ -588,6 +602,9 @@
   ** signed.
   ** (PGP only)
   */
+  { "file_charset",	DT_SYN, R_NONE, UL "attach_charset", 0 },
+  /*
+  */
   { "folder",		DT_PATH, R_NONE, UL &Maildir, UL "~/Mail" },
   /*
   ** .pp
diff -uNr mutt-1.5.14.orig/mutt.h mutt-1.5.14/mutt.h
--- mutt-1.5.14.orig/mutt.h	2007-01-31 04:49:02.000000000 +0900
+++ mutt-1.5.14/mutt.h	2007-02-26 00:04:04.000000000 +0900
@@ -641,6 +641,7 @@
 				 * If NULL, filename is used 
 				 * instead.
 				 */
+  char *charset;                /* charset of attached file */
   CONTENT *content;             /* structure used to store detailed info about
 				 * the content of the attachment.  this is used
 				 * to determine what content-transfer-encoding
diff -uNr mutt-1.5.14.orig/sendlib.c mutt-1.5.14/sendlib.c
--- mutt-1.5.14.orig/sendlib.c	2007-01-31 04:49:04.000000000 +0900
+++ mutt-1.5.14/sendlib.c	2007-02-26 00:04:04.000000000 +0900
@@ -442,7 +442,7 @@
   }
 
   if (a->type == TYPETEXT && (!a->noconv))
-    fc = fgetconv_open (fpin, Charset, 
+    fc = fgetconv_open (fpin, a->charset, 
 			mutt_get_body_charset (send_charset, sizeof (send_charset), a),
 			0);
   else
@@ -842,6 +842,7 @@
   CONTENT *info;
   CONTENT_STATE state;
   FILE *fp = NULL;
+  char *fromcode;
   char *tocode;
   char buffer[100];
   char chsbuf[STRING];
@@ -876,15 +877,18 @@
   if (b != NULL && b->type == TYPETEXT && (!b->noconv && !b->force_charset))
   {
     char *chs = mutt_get_parameter ("charset", b->parameter);
+    char *fchs = b->use_disp ? ((AttachCharset && *AttachCharset) ?
+                                AttachCharset : Charset) : Charset;
     if (Charset && (chs || SendCharset) &&
-	convert_file_from_to (fp, Charset, chs ? chs : SendCharset,
-			      0, &tocode, info) != (size_t)(-1))
+        convert_file_from_to (fp, fchs, chs ? chs : SendCharset,
+                              &fromcode, &tocode, info) != (size_t)(-1))
     {
       if (!chs)
       {
 	mutt_canonical_charset (chsbuf, sizeof (chsbuf), tocode);
 	mutt_set_parameter ("charset", chsbuf, &b->parameter);
       }
+      b->charset = fromcode;
       FREE (&tocode);
       safe_fclose (&fp);
       return info;
@@ -1267,6 +1271,7 @@
   body->unlink = 1;
   body->use_disp = 0;
   body->disposition = DISPINLINE;
+  body->noconv = 1;
 
   mutt_parse_mime_message (ctx, hdr);
 
diff -uNr mutt-1.5.14.orig/PATCHES mutt-1.5.14/PATCHES
--- mutt-1.5.14.orig/PATCHES	2006-10-30 11:30:55.000000000 +0900
+++ mutt-1.5.14/PATCHES	2007-02-26 00:04:15.000000000 +0900
@@ -0,0 +1 @@
+patch-1.5.14.tt.attach_charset.1
